Description Usage Arguments Value
View source: R/dashboardPlot.R
dashboardPlot Creates an interactive Shiny plot to explore results
generated in the function excessCases. Drop down menus
allow for viewing different syndromes, age groups, and geographies, and
for looking at plots of raw counts, proportions, or Observed/Expected.
1 | dashboardPlot(all.glm.res)
|
all.glm.res |
Provide the object returned by the function
|
Returns an object representing the shinyapp. Depending on the
environment (RStudio vs. console) the app may then be passed to
print(), which will start the server. Refer to
link[shiny]{shinyApp} for more details.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.